diff --git a/scripts/Makefile b/scripts/Makefile
index e4dd177f8b..fdf48cefc1 100644
--- a/scripts/Makefile
+++ b/scripts/Makefile
@@ -15,9 +15,6 @@ include assembly-load-context.mk
# main references to the CoreCLR reference assemblies
include coreref.mk
-# make file which adds things that are necessary for the platform we are building for
-include platform.mk
-
# builds unit tests
include tests.mk
@@ -63,8 +60,8 @@ RUN_TARGETS=$(POWERSHELL_RUN_TARGETS) dotnetlibs/Microsoft.PowerShell.Commands.M
all: dotnetlibs/System.Management.Automation.dll $(RUN_TARGETS) dotnetlibs/$(ASSEMBLY_LOAD_CONTEXT_TARGET)
# this is the build rule for SMA.dll
-dotnetlibs/System.Management.Automation.dll: $(SYS_AUTO_SRCS) dotnetlibs/Microsoft.Management.Infrastructure.dll ../src/assembly-info/System.Management.Automation.assembly-info.cs dotnetlibs/$(ASSEMBLY_LOAD_CONTEXT_TARGET) $(PLATFORM_SRCS) $(SYS_AUTO_RES_SRCS) $(SYS_AUTO_RES_CS_SRCS)
- $(CSC) -out:$@ $(MCSOPTS_LIB) $(PRODUCT_PS_REFS) $(SYS_AUTO_SRCS) $(SYS_AUTO_RES_REF) $(SYS_AUTO_RES_CS_SRCS) $(PLATFORM_SRCS) ../src/assembly-info/System.Management.Automation.assembly-info.cs
+dotnetlibs/System.Management.Automation.dll: $(SYS_AUTO_SRCS) dotnetlibs/Microsoft.Management.Infrastructure.dll ../src/assembly-info/System.Management.Automation.assembly-info.cs dotnetlibs/$(ASSEMBLY_LOAD_CONTEXT_TARGET) $(SYS_AUTO_RES_SRCS) $(SYS_AUTO_RES_CS_SRCS)
+ $(CSC) -out:$@ $(MCSOPTS_LIB) $(PRODUCT_PS_REFS) $(SYS_AUTO_SRCS) $(SYS_AUTO_RES_REF) $(SYS_AUTO_RES_CS_SRCS) ../src/assembly-info/System.Management.Automation.assembly-info.cs
# this is the build rule for MMI.dll
dotnetlibs/Microsoft.Management.Infrastructure.dll: $(MAN_INFRA_SRCS) dotnetlibs/Microsoft.Management.Infrastructure.Native.dll ../src/assembly-info/Microsoft.Management.Infrastructure.assembly-info.cs $(MAN_INFRA_RES_SRCS) $(MAN_INFRA_RES_CS_SRCS)
diff --git a/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.cs b/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.cs
index 9226f7776b..c88c1736a6 100644
--- a/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.cs
+++ b/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.cs
@@ -61,6 +61,15 @@ internal class NewObjectStrings {
}
}
+ ///
+ /// Looks up a localized string similar to {0} Please note that Single-Threaded Apartment is not supported in OneCore PowerShell..
+ ///
+ internal static string ApartmentNotSupported {
+ get {
+ return ResourceManager.GetString("ApartmentNotSupported", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Cannot create type. Only core types are supported in this language mode..
///
@@ -106,15 +115,6 @@ internal class NewObjectStrings {
}
}
- ///
- /// Looks up a localized string similar to Cannot create the COM object. COM object is not supported in OneCore PowerShell..
- ///
- internal static string ComObjectNotSupportedInOneCorePowerShell {
- get {
- return ResourceManager.GetString("ComObjectNotSupportedInOneCorePowerShell", resourceCulture);
- }
- }
-
///
/// Looks up a localized string similar to The value supplied is not valid, or the property is read-only. Change the value, and then try again..
///
diff --git a/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.resources b/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.resources
index c72011193e..6b0317df92 100644
Binary files a/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.resources and b/scripts/gen/COMMANDS_UTILITY/NewObjectStrings.resources differ
diff --git a/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.cs b/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.cs
index d747551f85..7ccfff9946 100644
--- a/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.cs
+++ b/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.cs
@@ -70,6 +70,15 @@ internal class UtilityCommonStrings {
}
}
+ ///
+ /// Looks up a localized string similar to The file '{0}' could not be parsed as a PowerShell Data File..
+ ///
+ internal static string CouldNotParseAsPowerShellDataFile {
+ get {
+ return ResourceManager.GetString("CouldNotParseAsPowerShellDataFile", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to This command cannot be run because '{0}' is empty or blank. Please specify CSSUri and then run the command..
///
diff --git a/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.resources b/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.resources
index e0a0150a8e..f371c16eb5 100644
Binary files a/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.resources and b/scripts/gen/COMMANDS_UTILITY/UtilityCommonStrings.resources differ
diff --git a/scripts/gen/SYS_AUTO/AutomationExceptions.cs b/scripts/gen/SYS_AUTO/AutomationExceptions.cs
index 911159e193..c9cda86f30 100644
--- a/scripts/gen/SYS_AUTO/AutomationExceptions.cs
+++ b/scripts/gen/SYS_AUTO/AutomationExceptions.cs
@@ -268,6 +268,15 @@ internal class AutomationExceptions {
}
}
+ ///
+ /// Looks up a localized string similar to Cannot process argument because the value of argument "{0}" is not valid. Valid values are "Global", "Local", or "Script", or a number relative to the current scope (0 through the number of scopes where 0 is the current scope and 1 is its parent). Change the value of the "{0}" argument and run the operation again..
+ ///
+ internal static string InvalidScopeIdArgument {
+ get {
+ return ResourceManager.GetString("InvalidScopeIdArgument", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Cannot perform operation because operation "{0}" is not implemented..
///
diff --git a/scripts/gen/SYS_AUTO/AutomationExceptions.resources b/scripts/gen/SYS_AUTO/AutomationExceptions.resources
index 169b1acbef..c0cfdabdcf 100644
Binary files a/scripts/gen/SYS_AUTO/AutomationExceptions.resources and b/scripts/gen/SYS_AUTO/AutomationExceptions.resources differ
diff --git a/scripts/gen/SYS_AUTO/DebuggerStrings.cs b/scripts/gen/SYS_AUTO/DebuggerStrings.cs
index 9462054cd7..6a89f08042 100644
--- a/scripts/gen/SYS_AUTO/DebuggerStrings.cs
+++ b/scripts/gen/SYS_AUTO/DebuggerStrings.cs
@@ -89,7 +89,7 @@ internal class DebuggerStrings {
}
///
- /// Looks up a localized string similar to The line count must be a positive integer no greater than {0}..
+ /// Looks up a localized string similar to The line count must be a positive integer..
///
internal static string BadCountFormat {
get {
diff --git a/scripts/gen/SYS_AUTO/Modules.resources b/scripts/gen/SYS_AUTO/Modules.resources
index 41f1da8c5c..e21385a99b 100644
Binary files a/scripts/gen/SYS_AUTO/Modules.resources and b/scripts/gen/SYS_AUTO/Modules.resources differ
diff --git a/scripts/gen/SYS_AUTO/ParserStrings.cs b/scripts/gen/SYS_AUTO/ParserStrings.cs
index b8fe6662bc..82d51f4f34 100644
--- a/scripts/gen/SYS_AUTO/ParserStrings.cs
+++ b/scripts/gen/SYS_AUTO/ParserStrings.cs
@@ -425,7 +425,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to Cannot run a document in OneCore powershell: {0}..
+ /// Looks up a localized string similar to Cannot run a document in OneCore PowerShell: {0}..
///
internal static string CantActivateDocumentOnOneCore {
get {
@@ -551,7 +551,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to Configuration keyword is not supported in OneCore powershell..
+ /// Looks up a localized string similar to Configuration keyword is not supported in OneCore PowerShell..
///
internal static string ConfigurationNotSupportedOnOneCore {
get {
@@ -1272,7 +1272,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to The format of the resource reference '{0}' in the Requires list for resource '{1}' is not valid. A required resource name should be in the format '[<typename>]<name>', with no spaces..
+ /// Looks up a localized string similar to The format of the resource reference '{0}' in the Requires list for resource '{1}' is not valid. A required resource name should be in the format '[<typename>]<name>', with alphanumeric characters, spaces, '_', '-', '.' and '\'..
///
internal static string GetBadlyFormedRequiredResourceId {
get {
@@ -1476,7 +1476,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to The default AssemblyLoadContext in use is invalid. The default AssemblyLoadContext for OneCore powershell should be of type 'PowerShellAssemblyLoadContext'..
+ /// Looks up a localized string similar to The default AssemblyLoadContext in use is invalid. The default AssemblyLoadContext for OneCore PowerShell should be of type 'PowerShellAssemblyLoadContext'..
///
internal static string InvalidAssemblyLoadContextInUse {
get {
@@ -2584,7 +2584,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to The DSC engine could not load the module '{0}'. It was not found on the system..
+ /// Looks up a localized string similar to Could not find the module '{0}'..
///
internal static string ModuleNotFoundDuringParse {
get {
@@ -2593,25 +2593,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to Unable to load module '{0}' : {1}.
- ///
- internal static string ModuleNotFoundDuringParseDueToException {
- get {
- return ResourceManager.GetString("ModuleNotFoundDuringParseDueToException", resourceCulture);
- }
- }
-
- ///
- /// Looks up a localized string similar to The DSC engine could not load the module <{0}, {1}>. It was not found on the system..
- ///
- internal static string ModuleWithVersionNotFoundDuringParse {
- get {
- return ResourceManager.GetString("ModuleWithVersionNotFoundDuringParse", resourceCulture);
- }
- }
-
- ///
- /// Looks up a localized string similar to Multiple versions of the module '{0}' were found. You can run 'Get-DscResource -Module {0}' to see available versions on the system, and then use the fully qualified name in the following command to specify the desired version: 'Import-DscResource –ModuleName @{{ModuleName="{0}";ModuleVersion="Version"}}'..
+ /// Looks up a localized string similar to Multiple versions of the module '{0}' were found. You can run 'Get-Module -ListAvailable -FullyQualifiedName {0}' to see available versions on the system, and then use the fully qualified name '@{{ModuleName="{0}"; RequiredVersion="Version"}}'..
///
internal static string MultipleModuleEntriesFoundDuringParse {
get {
@@ -2898,15 +2880,6 @@ internal class ParserStrings {
}
}
- ///
- /// Looks up a localized string similar to The parameter attribute is not allowed on a method parameter..
- ///
- internal static string ParameterAttributeNotAllowedInMethod {
- get {
- return ResourceManager.GetString("ParameterAttributeNotAllowedInMethod", resourceCulture);
- }
- }
-
///
/// Looks up a localized string similar to Parameter {0} cannot have an argument..
///
@@ -3946,7 +3919,7 @@ internal class ParserStrings {
}
///
- /// Looks up a localized string similar to Workflow is not supported in OneCore powershell..
+ /// Looks up a localized string similar to Workflow is not supported in OneCore PowerShell..
///
internal static string WorkflowNotSupportedOnOneCore {
get {
diff --git a/scripts/gen/SYS_AUTO/ParserStrings.resources b/scripts/gen/SYS_AUTO/ParserStrings.resources
index 7efbef9ebf..c84df64b14 100644
Binary files a/scripts/gen/SYS_AUTO/ParserStrings.resources and b/scripts/gen/SYS_AUTO/ParserStrings.resources differ
diff --git a/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.cs b/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.cs
index c8eb48f795..1bb3258f9f 100644
--- a/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.cs
+++ b/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.cs
@@ -250,15 +250,6 @@ internal class RemotingErrorIdStrings {
}
}
- ///
- /// Looks up a localized string similar to Failed to find vmcompute.dll. The Hyper-V role may not be enabled on this machine..
- ///
- internal static string CannotFindVmComputeDll {
- get {
- return ResourceManager.GetString("CannotFindVmComputeDll", resourceCulture);
- }
- }
-
///
/// Looks up a localized string similar to The call to Windows API GetStdHandle to get the Standard Error handle resulted in an error code: {0}..
///
@@ -548,11 +539,38 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Could not find the toolkit, '{0}'. The toolkit must be a file named '{1}' within a 'Toolkits' directory in a module in the current module path..
+ /// Looks up a localized string similar to The Containers feature may not be enabled on this machine..
///
- internal static string CouldNotFindToolkit {
+ internal static string ContainersFeatureNotEnabled {
get {
- return ResourceManager.GetString("CouldNotFindToolkit", resourceCulture);
+ return ResourceManager.GetString("ContainersFeatureNotEnabled", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Could not find the role capability, '{0}'. The role capability must be a file named '{1}' within a 'RoleCapabilities' directory in a module in the current module path..
+ ///
+ internal static string CouldNotFindRoleCapability {
+ get {
+ return ResourceManager.GetString("CouldNotFindRoleCapability", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Could not grant remote access to '{0}': '{1}'. The session configuration has been registered, but this group does not have access. To resolve this error, provide a valid group name and register the session configuration again..
+ ///
+ internal static string CouldNotResolveRoleDefinitionPrincipal {
+ get {
+ return ResourceManager.GetString("CouldNotResolveRoleDefinitionPrincipal", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Could not resolve username '{0}'. Verify the username and try again..
+ ///
+ internal static string CouldNotResolveUsername {
+ get {
+ return ResourceManager.GetString("CouldNotResolveUsername", resourceCulture);
}
}
@@ -750,7 +768,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Aliases defined in this session configuration.
+ /// Looks up a localized string similar to Aliases to be defined when applied to a session.
///
internal static string DISCAliasDefinitionsComment {
get {
@@ -759,7 +777,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Assemblies that will be loaded in this session configuration.
+ /// Looks up a localized string similar to Assemblies to load when applied to a session.
///
internal static string DISCAssembliesToLoadComment {
get {
@@ -768,7 +786,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Author of this session configuration.
+ /// Looks up a localized string similar to Author of this document.
///
internal static string DISCAuthorComment {
get {
@@ -777,7 +795,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Version of the CLR used by this session configuration.
+ /// Looks up a localized string similar to Version of the CLR to use when applied to a session.
///
internal static string DISCCLRVersionComment {
get {
@@ -795,7 +813,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Company associated with this session configuration.
+ /// Looks up a localized string similar to Company associated with this document.
///
internal static string DISCCompanyNameComment {
get {
@@ -804,7 +822,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Copyright statement for this session configuration.
+ /// Looks up a localized string similar to Copyright statement for this document.
///
internal static string DISCCopyrightComment {
get {
@@ -813,7 +831,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Description of the functionality provided by this session configuration.
+ /// Looks up a localized string similar to Description of the functionality provided by these settings.
///
internal static string DISCDescriptionComment {
get {
@@ -822,7 +840,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Environment variables defined in this session configuration.
+ /// Looks up a localized string similar to Environment variables to define when applied to a session.
///
internal static string DISCEnvironmentVariablesComment {
get {
@@ -840,7 +858,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Specifies the execution policy for this session configuration.
+ /// Looks up a localized string similar to Execution policy to apply when applied to a session.
///
internal static string DISCExecutionPolicyComment {
get {
@@ -849,7 +867,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Format files (.ps1xml) that will be loaded in this session configuration..
+ /// Looks up a localized string similar to Format files (.ps1xml) to load when applied to a session.
///
internal static string DISCFormatsToProcessComment {
get {
@@ -858,7 +876,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Functions defined in this session configuration.
+ /// Looks up a localized string similar to Functions to define when applied to a session.
///
internal static string DISCFunctionDefinitionsComment {
get {
@@ -867,7 +885,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to ID used to uniquely identify this session configuration..
+ /// Looks up a localized string similar to ID used to uniquely identify this document.
///
internal static string DISCGUIDComment {
get {
@@ -876,7 +894,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Initial state of this session configuration.
+ /// Looks up a localized string similar to Session type defaults to apply for this session configuration.
///
internal static string DISCInitialSessionStateComment {
get {
@@ -912,7 +930,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Modules that will be imported.
+ /// Looks up a localized string similar to Language mode to apply when applied to a session.
///
internal static string DISCLanguageModeComment {
get {
@@ -930,7 +948,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Modules that will be imported..
+ /// Looks up a localized string similar to Modules to import when applied to a session.
///
internal static string DISCModulesToImportComment {
get {
@@ -966,7 +984,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Version of the Windows PowerShell engine used by this session configuration.
+ /// Looks up a localized string similar to Version of the Windows PowerShell engine to use when applied to a session.
///
internal static string DISCPowerShellVersionComment {
get {
@@ -975,7 +993,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Processor architecture used by this session configuration.
+ /// Looks up a localized string similar to Processor architecture to use when applied to a session.
///
internal static string DISCProcessorArchitectureComment {
get {
@@ -984,7 +1002,16 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to User roles (security groups), and the additional configuration settings that should be applied to them.
+ /// Looks up a localized string similar to Role Capabilities to apply to this session configuration. This role capability must be defined as a PowerShell Role Capability (.psrc) file named after that role capability within a 'RoleCapabilities' directory in a module in the current module path..
+ ///
+ internal static string DISCRoleCapabilitiesToLoadComment {
+ get {
+ return ResourceManager.GetString("DISCRoleCapabilitiesToLoadComment", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to User roles (security groups), and the role capabilities that should be applied to them when applied to a session.
///
internal static string DISCRoleDefinitionsComment {
get {
@@ -993,7 +1020,16 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Version number of the schema used for this configuration file.
+ /// Looks up a localized string similar to Whether to run this session configuration as the machine's (virtual) administrator account.
+ ///
+ internal static string DISCRunAsVirtualAccountComment {
+ get {
+ return ResourceManager.GetString("DISCRunAsVirtualAccountComment", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Version number of the schema used for this document.
///
internal static string DISCSchemaVersionComment {
get {
@@ -1002,7 +1038,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Specifies the scripts to run after the session is configured.
+ /// Looks up a localized string similar to Scripts to run when applied to a session.
///
internal static string DISCScriptsToProcessComment {
get {
@@ -1011,20 +1047,11 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Toolkits to apply to this session configuration. This toolkit must be defined as a session configuration file named after that toolkit within a 'Toolkits' directory in a module in the current module path..
+ /// Looks up a localized string similar to Directory to place session transcripts for this session configuration.
///
- internal static string DISCToolkitsToLoadComment {
+ internal static string DISCTranscriptDirectoryComment {
get {
- return ResourceManager.GetString("DISCToolkitsToLoadComment", resourceCulture);
- }
- }
-
- ///
- /// Looks up a localized string similar to Specifies the transport options for this session configuration.
- ///
- internal static string DISCTransportOptionsComment {
- get {
- return ResourceManager.GetString("DISCTransportOptionsComment", resourceCulture);
+ return ResourceManager.GetString("DISCTranscriptDirectoryComment", resourceCulture);
}
}
@@ -1110,7 +1137,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Types to add to this session configuration.
+ /// Looks up a localized string similar to Types to add when applied to a session.
///
internal static string DISCTypesToAddComment {
get {
@@ -1119,7 +1146,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Type files (.ps1xml) that will be loaded in this session configuration.
+ /// Looks up a localized string similar to Type files (.ps1xml) to load when applied to a session.
///
internal static string DISCTypesToProcessComment {
get {
@@ -1128,7 +1155,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Variables defined in this session configuration.
+ /// Looks up a localized string similar to Variables to define when applied to a session.
///
internal static string DISCVariableDefinitionsComment {
get {
@@ -1146,7 +1173,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Aliases visible in this session configuration.
+ /// Looks up a localized string similar to Aliases to make visible when applied to a session.
///
internal static string DISCVisibleAliasesComment {
get {
@@ -1155,7 +1182,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Cmdlets visible in this session configuration.
+ /// Looks up a localized string similar to Cmdlets to make visible when applied to a session.
///
internal static string DISCVisibleCmdletsComment {
get {
@@ -1164,7 +1191,16 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Functions visible in this session configuration.
+ /// Looks up a localized string similar to External commands (scripts and applications) to make visible when applied to a session.
+ ///
+ internal static string DISCVisibleExternalCommandsComment {
+ get {
+ return ResourceManager.GetString("DISCVisibleExternalCommandsComment", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to Functions to make visible when applied to a session.
///
internal static string DISCVisibleFunctionsComment {
get {
@@ -1173,7 +1209,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to Providers visible in this session configuration.
+ /// Looks up a localized string similar to Providers to make visible when applied to a session.
///
internal static string DISCVisibleProvidersComment {
get {
@@ -1657,7 +1693,7 @@ internal class RemotingErrorIdStrings {
}
///
- /// Looks up a localized string similar to PSSession Configuration File path '{0}' is not valid. The path argument must resolve to a single file in the file system with a '.pssc' extension. Please fix the path specification and try again..
+ /// Looks up a localized string similar to PSSession Configuration file path '{0}' is not valid. The path argument must resolve to a single file in the file system with a '.pssc' extension. Please fix the path specification and try again..
///
internal static string InvalidPSSessionConfigurationFilePath {
get {
@@ -1674,6 +1710,24 @@ internal class RemotingErrorIdStrings {
}
}
+ ///
+ /// Looks up a localized string similar to Role Capability file path '{0}' is not valid. The path argument must resolve to a single file in the file system with a '.psrc' extension. Please fix the path specification and try again..
+ ///
+ internal static string InvalidRoleCapabilityFilePath {
+ get {
+ return ResourceManager.GetString("InvalidRoleCapabilityFilePath", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to The key '{0}' is not valid in a role capability or role definition..
+ ///
+ internal static string InvalidRoleCapabilityKey {
+ get {
+ return ResourceManager.GetString("InvalidRoleCapabilityKey", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to The 'Roles' entry must be a hashtable, but was a {0}..
///
@@ -1683,15 +1737,6 @@ internal class RemotingErrorIdStrings {
}
}
- ///
- /// Looks up a localized string similar to The key '{0}' is not valid in a toolkit or role definition..
- ///
- internal static string InvalidRoleToolkitKey {
- get {
- return ResourceManager.GetString("InvalidRoleToolkitKey", resourceCulture);
- }
- }
-
///
/// Looks up a localized string similar to Could not convert the value of the '{0}' role entry to a hashtable. The 'Roles' entry must be a hashtable with group names for keys, where the value associated with each key is another hashtable of session configuration properties for that role..
///
@@ -2250,6 +2295,15 @@ internal class RemotingErrorIdStrings {
}
}
+ ///
+ /// Looks up a localized string similar to Unable to start named pipe server while in server mode..
+ ///
+ internal static string NamedPipeServerCannotStart {
+ get {
+ return ResourceManager.GetString("NamedPipeServerCannotStart", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to "The named pipe target process has ended.".
///
@@ -3521,6 +3575,15 @@ internal class RemotingErrorIdStrings {
}
}
+ ///
+ /// Looks up a localized string similar to Could not get the session capabilities for the session configuration '{0}': this configuration was not registered with a session configuration file (.pssc), such as one created by the New-PSSessionConfigurationFile cmdlet..
+ ///
+ internal static string SessionConfigurationMustBeFileBased {
+ get {
+ return ResourceManager.GetString("SessionConfigurationMustBeFileBased", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to A failure occurred while attempting to connect the PSSession..
///
diff --git a/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.resources b/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.resources
index f3a113e04a..de3571e7fd 100644
Binary files a/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.resources and b/scripts/gen/SYS_AUTO/RemotingErrorIdStrings.resources differ
diff --git a/scripts/platform.mk b/scripts/platform.mk
deleted file mode 100644
index 309fb77e47..0000000000
--- a/scripts/platform.mk
+++ /dev/null
@@ -1,4 +0,0 @@
-# platform specifics
-
-PLATFORM_SRCS=../src/monad/monad/src/CoreCLR/CorePsPlatform.cs
-
diff --git a/scripts/system-automation.mk b/scripts/system-automation.mk
index da1bbfa3df..b0cdd93075 100644
--- a/scripts/system-automation.mk
+++ b/scripts/system-automation.mk
@@ -102,9 +102,19 @@ SYS_AUTO_SRCS_WIN=\
../../../jws/pswin/admin/monad/src/engine/MshMemberInfo.cs \
../../../jws/pswin/admin/monad/src/engine/MshObject.cs \
../../../jws/pswin/admin/monad/src/engine/TypeTable.cs \
+ ../../../jws/pswin/admin/monad/src/engine/Types_Ps1Xml.generated.cs \
+ ../../../jws/pswin/admin/monad/src/engine/TypesV3_Ps1Xml.generated.cs \
+ ../../../jws/pswin/admin/monad/src/engine/GetEvent_Types_Ps1Xml.generated.cs \
../../../jws/pswin/admin/monad/src/engine/ExtendedTypeSystemException.cs \
../../../jws/pswin/admin/monad/src/engine/MshReference.cs \
../../../jws/pswin/admin/monad/src/engine/WinRT/IInspectable.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComAdapter.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComDispatch.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComInvoker.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComMethod.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComProperty.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComTypeInfo.cs \
+ ../../../jws/pswin/admin/monad/src/engine/COM/ComUtil.cs \
../../../jws/pswin/admin/monad/src/help/CabinetAPI.cs \
../../../jws/pswin/admin/monad/src/help/CabinetNativeApi.cs \
../../../jws/pswin/admin/monad/src/help/MamlUtil.cs \
@@ -300,6 +310,7 @@ SYS_AUTO_SRCS_WIN=\
../../../jws/pswin/admin/monad/src/engine/Utils.cs \
../../../jws/pswin/admin/monad/src/engine/regex.cs \
../../../jws/pswin/admin/monad/src/engine/serialization.cs \
+ ../../../jws/pswin/admin/monad/src/CoreCLR/CorePsPlatform.cs \
../../../jws/pswin/admin/monad/src/engine/DataStoreAdapter.cs \
../../../jws/pswin/admin/monad/src/engine/DataStoreAdapterProvider.cs \
../../../jws/pswin/admin/monad/src/namespaces/ContainerProviderBase.cs \
@@ -523,6 +534,8 @@ SYS_AUTO_SRCS_WIN=\
../../../jws/pswin/admin/monad/src/utils/PInvokeDllNames.cs \
../../../jws/pswin/admin/monad/src/utils/PlatformInvokes.cs \
../../../jws/pswin/admin/monad/src/utils/ClrFacade.cs \
+ ../../../jws/pswin/admin/monad/src/utils/PSTelemetryWrapper.cs \
+ ../../../jws/pswin/admin/monad/src/utils/PSTelemetryMethods.cs \
../../../jws/pswin/admin/monad/src/commands/utility/FormatAndOutput/common/Utilities/MshObjectUtil.cs \
../../../jws/pswin/admin/monad/src/commands/utility/FormatAndOutput/common/Utilities/Mshexpression.cs \
../../../jws/pswin/admin/monad/src/commands/utility/FormatAndOutput/common/DisplayDatabase/XmlLoaderBase.cs \
@@ -667,9 +680,19 @@ SYS_AUTO_SRCS=\
$(ADMIN_GIT_ROOT)/monad/src/engine/MshMemberInfo.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/MshObject.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/TypeTable.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/Types_Ps1Xml.generated.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/TypesV3_Ps1Xml.generated.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/GetEvent_Types_Ps1Xml.generated.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/ExtendedTypeSystemException.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/MshReference.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/WinRT/IInspectable.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComAdapter.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComDispatch.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComInvoker.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComMethod.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComProperty.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComTypeInfo.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/engine/COM/ComUtil.cs \
$(ADMIN_GIT_ROOT)/monad/src/help/CabinetAPI.cs \
$(ADMIN_GIT_ROOT)/monad/src/help/CabinetNativeApi.cs \
$(ADMIN_GIT_ROOT)/monad/src/help/MamlUtil.cs \
@@ -865,6 +888,7 @@ SYS_AUTO_SRCS=\
$(ADMIN_GIT_ROOT)/monad/src/engine/Utils.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/regex.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/serialization.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/CoreCLR/CorePsPlatform.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/DataStoreAdapter.cs \
$(ADMIN_GIT_ROOT)/monad/src/engine/DataStoreAdapterProvider.cs \
$(ADMIN_GIT_ROOT)/monad/src/namespaces/ContainerProviderBase.cs \
@@ -1088,6 +1112,8 @@ SYS_AUTO_SRCS=\
$(ADMIN_GIT_ROOT)/monad/src/utils/PInvokeDllNames.cs \
$(ADMIN_GIT_ROOT)/monad/src/utils/PlatformInvokes.cs \
$(ADMIN_GIT_ROOT)/monad/src/utils/ClrFacade.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/utils/PSTelemetryWrapper.cs \
+ $(ADMIN_GIT_ROOT)/monad/src/utils/PSTelemetryMethods.cs \
$(ADMIN_GIT_ROOT)/monad/src/commands/utility/FormatAndOutput/common/Utilities/MshObjectUtil.cs \
$(ADMIN_GIT_ROOT)/monad/src/commands/utility/FormatAndOutput/common/Utilities/Mshexpression.cs \
$(ADMIN_GIT_ROOT)/monad/src/commands/utility/FormatAndOutput/common/DisplayDatabase/XmlLoaderBase.cs \
diff --git a/src/monad b/src/monad
index 378897d1d5..105169ff72 160000
--- a/src/monad
+++ b/src/monad
@@ -1 +1 @@
-Subproject commit 378897d1d5cf19e63fb7faefd301eca6624daf38
+Subproject commit 105169ff725b1d1ddfe0b4e018ac780e485ab3a7
diff --git a/scripts/gen/SYS_AUTO/DebuggerStrings.resources b/scripts/gen/SYS_AUTO/DebuggerStrings.resources
index a5c5f2d8fd..1e9bb7b6bc 100644
Binary files a/scripts/gen/SYS_AUTO/DebuggerStrings.resources and b/scripts/gen/SYS_AUTO/DebuggerStrings.resources differ
diff --git a/scripts/gen/SYS_AUTO/Modules.cs b/scripts/gen/SYS_AUTO/Modules.cs
index 4681cb79df..1698dd5e6c 100644
--- a/scripts/gen/SYS_AUTO/Modules.cs
+++ b/scripts/gen/SYS_AUTO/Modules.cs
@@ -764,6 +764,42 @@ internal class Modules {
}
}
+ ///
+ /// Looks up a localized string similar to The specified MaximumVersion '{0}' was incorrect. If you are using '*', MaximumVersion only supports one '*' and should always be placed at the end of MaximumVersion..
+ ///
+ internal static string MaximumVersionFormatIncorrect {
+ get {
+ return ResourceManager.GetString("MaximumVersionFormatIncorrect", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to The specified module '{0}' with MaximumVersion '{1}' was not loaded because no valid module file was found in any module directory..
+ ///
+ internal static string MaximumVersionNotFound {
+ get {
+ return ResourceManager.GetString("MaximumVersionNotFound", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to The MinimumVersion '{0}' should not be greater than MaximumVersion '{1}'..
+ ///
+ internal static string MinimumVersionAndMaximumVersionInvalidRange {
+ get {
+ return ResourceManager.GetString("MinimumVersionAndMaximumVersionInvalidRange", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to The specified module '{0}' with MinimumVersion '{1}' and MaximumVersion '{2}' was not loaded because no valid module file was found in any module directory..
+ ///
+ internal static string MinimumVersionAndMaximumVersionNotFound {
+ get {
+ return ResourceManager.GetString("MinimumVersionAndMaximumVersionNotFound", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Some commands from module {0} cannot be imported over a CimSession. To get all the commands, verify that the remote server has Windows PowerShell remote management enabled, and then try adding the PSSession parameter to an Import-Module cmdlet..
///
@@ -1224,7 +1260,7 @@ internal class Modules {
}
///
/// Looks up a localized string similar to The 'ModuleVersion' and 'RequiredVersion' members do not exist in the hashtable that describes this module. One of these two members must exist, and be assigned a version number in the format 'n.n.n.n'..
///
internal static string RequiredModuleMissingModuleVersion {
get {
@@ -1268,6 +1304,24 @@ internal class Modules {
}
}
+ ///
+ /// Looks up a localized string similar to The required module '{1}' with MaximumVersion '{2}' is not loaded. Load the module or remove the module from 'RequiredModules' in the file '{0}'..
+ ///
+ internal static string RequiredModuleNotLoadedWrongMaximumVersion {
+ get {
+ return ResourceManager.GetString("RequiredModuleNotLoadedWrongMaximumVersion", resourceCulture);
+ }
+ }
+
+ ///
+ /// Looks up a localized string similar to The required module '{1}' with MinimumVersion '{2}' and MaximumVersion '{3}' is not loaded. Load the module or remove the module from 'RequiredModules' in the file '{0}'..
+ ///
+ internal static string RequiredModuleNotLoadedWrongMinimumVersionAndMaximumVersion {
+ get {
+ return ResourceManager.GetString("RequiredModuleNotLoadedWrongMinimumVersionAndMaximumVersion", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to The required module '{1}' with version '{2}' is not loaded. Load the module or remove the module from 'RequiredModules' in the file '{0}'..
///
@@ -1224,7 +1260,7 @@ internal class Modules {
}
///
- /// Looks up a localized string similar to The 'ModuleVersion' and 'RequiredVersion' members do not exist in the hashtable that describes this module. One of these two members must exist, and be assigned a version number in the format 'n.n.n.n'..
+ /// Looks up a localized string similar to The 'ModuleVersion', 'MaximumVersion' and 'RequiredVersion' members do not exist in the hashtable that describes this module. One of these three members must exist, and be assigned a version number in the format 'n.n.n.n'..
///
internal static string RequiredModuleMissingModuleVersion {